summaryrefslogtreecommitdiffstats
path: root/src/Blocks/BlockLilypad.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/Blocks/BlockLilypad.h')
-rw-r--r--src/Blocks/BlockLilypad.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/Blocks/BlockLilypad.h b/src/Blocks/BlockLilypad.h
index 398d2b64b..9c4edaecc 100644
--- a/src/Blocks/BlockLilypad.h
+++ b/src/Blocks/BlockLilypad.h
@@ -35,8 +35,8 @@ public:
NIBBLETYPE UnderMeta;
a_Chunk.GetBlockTypeMeta(a_RelX, a_RelY - 1, a_RelZ, UnderType, UnderMeta);
return (
- ((UnderType == E_BLOCK_STATIONARY_WATER) || (UnderType == E_BLOCK_WATER)) && // Water is below...
- (UnderMeta == 0) // ... and it's a source
+ (((UnderType == E_BLOCK_STATIONARY_WATER) || (UnderType == E_BLOCK_WATER)) && (UnderMeta == 0)) || // A water source is below
+ (UnderType == E_BLOCK_ICE) || (UnderType == E_BLOCK_FROSTED_ICE) // Or (frosted) ice
);
}
};